#
# spec file
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "bootstrap"
%bcond_without bootstrap
%else
%bcond_with bootstrap
%endif
%global base_name tesla-polyglot
Version:        0.4.5
Release:        150200.3.4.4
URL:            https://github.com/takari/maven-polyglot
Source0:        https://github.com/takari/polyglot-maven/archive/polyglot-%{version}.tar.gz
Patch0:         polyglot-snakeyaml-1.25.patch
Patch1:         pomless-tycho.patch
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(commons-beanutils:commons-beanutils)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-model-builder)
BuildRequires:  mvn(org.codehaus.plexus:plexus-component-annotations)
BuildRequires:  mvn(org.codehaus.plexus:plexus-component-metadata)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.plexus)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildArch:      noarch
%if %{with bootstrap}
Name:           %{base_name}-common
Summary:        Polyglot Tesla :: Common
License:        EPL-1.0

%description
Polyglot Tesla :: Common.
%else
Name:           %{base_name}
Summary:        Modules to enable Maven usage in other JVM languages
License:        EPL-1.0
BuildRequires:  mvn(commons-logging:commons-logging)
# Built in the bootstrap phase
BuildRequires:  mvn(io.takari.polyglot:polyglot-common) = %{version}
# Maven plugins
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
# Yaml module
BuildRequires:  mvn(org.yaml:snakeyaml)
# Groovy module
BuildRequires:  mvn(org.codehaus.gmavenplus:gmavenplus-plugin)
BuildRequires:  mvn(org.codehaus.groovy:groovy)

%description
Polyglot for Maven is an experimental distribution of Maven
that allows the expression of a POM in something other than
XML. A couple of the dialects also have the capability to
write plugins inline: the Groovy, Ruby and Scala dialects
allow this.
%endif

%if %{without bootstrap}
%package atom
Summary:        Polyglot Tesla :: Atom

%description atom
Polyglot Tesla :: Atom.

%package groovy
Summary:        Polyglot Tesla :: Groovy

%description groovy
Polyglot Tesla :: Groovy.

%package java
Summary:        Polyglot Tesla :: Java

%description java
Polyglot Tesla :: Java.

%package yaml
Summary:        Polyglot Tesla :: YAML

%description yaml
Polyglot Tesla :: YAML.

%package maven-plugin
Summary:        Polyglot Tesla :: Maven Plugin

%description maven-plugin
This package contains Polyglot Tesla Maven Plugin.

%package translate-plugin
Summary:        Polyglot :: Translate Plugin

%description translate-plugin
This package contains Polyglot Translate Plugin.

%package xml
Summary:        Polyglot Tesla :: XML

%description xml
Polyglot Tesla :: XML.

%endif

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n polyglot-maven-polyglot-%{version}
%patch0 -p1
%patch1 -p1

find -name "*.class" -delete
find -name "*.jar" -delete

# Unavailable build deps/tools
%pom_disable_module polyglot-clojure
%pom_disable_module polyglot-scala
%pom_remove_dep -r :polyglot-scala
%pom_disable_module polyglot-ruby
%pom_remove_dep -r :polyglot-ruby
%pom_disable_module polyglot-kotlin
%pom_remove_dep -r :polyglot-kotlin

%pom_remove_parent
perl -pi -e 's#takari-jar#jar#g' */pom.xml
perl -pi -e 's#takari-maven-plugin#maven-plugin#g' */pom.xml

%if %{with bootstrap}
%pom_disable_module polyglot-atom
%pom_disable_module polyglot-groovy
%pom_disable_module polyglot-java
%pom_disable_module polyglot-maven-plugin
%pom_disable_module polyglot-translate-plugin
%pom_disable_module polyglot-xml
%pom_disable_module polyglot-yaml
%else
%pom_disable_module polyglot-common
%endif

%pom_remove_dep rubygems:maven-tools polyglot-ruby
rm -Rf polyglot-ruby/src/{test,it}
%pom_remove_plugin :maven-invoker-plugin polyglot-ruby
%pom_remove_plugin -r :maven-enforcer-plugin

# Unavailable plugin
%pom_remove_plugin org.codehaus.groovy:groovy-eclipse-compiler polyglot-groovy
%pom_remove_dep org.codehaus.groovy:groovy-eclipse-batch polyglot-groovy
%pom_remove_dep org.codehaus.groovy:groovy-eclipse-compiler polyglot-groovy
%pom_remove_plugin :maven-compiler-plugin polyglot-groovy
# use gmavenplus
%pom_add_plugin org.codehaus.gmavenplus:gmavenplus-plugin:1.5 polyglot-groovy "
 <executions>
  <execution>
   <goals>
    <goal>generateStubs</goal>
   </goals>
  </execution>
 </executions>"

for p in maven-plugin translate-plugin; do
  %pom_add_plugin "org.apache.maven.plugins:maven-plugin-plugin:3.4" polyglot-${p} "
  <configuration>
    <skipErrorNoDescriptorsFound>true</skipErrorNoDescriptorsFound>
  </configuration>"
%pom_xpath_inject "pom:dependency[pom:groupId = 'org.apache.maven']" "<version>3.3.1</version>" polyglot-${p}
done

%pom_xpath_inject "pom:project/pom:dependencies/pom:dependency[pom:groupId = 'org.apache.maven']" '<version>${mavenVersion}</version>'

# atom common maven-plugin translate-plugin
# diamond operator
for m in common yaml groovy
do
%pom_add_plugin org.apache.maven.plugins:maven-compiler-plugin:3.0 polyglot-${m} '
<configuration>
 <source>1.8</source>
 <target>1.8</target>
 <encoding>UTF-8</encoding>
</configuration>'
done

# Use web access
sed -i '/pyyaml/d' polyglot-yaml/src/test/java/org/sonatype/maven/polyglot/yaml/CompactFormatTest.java

# test skipped for unavailable dependency org.easytesting:fest-assert:1.1
rm -rf polyglot-clojure/src/test/java/*

# com.cedarsoftware:java-util:1.19.3
sed -i '/DeepEquals/d' polyglot-xml/src/test/java/org/sonatype/maven/polyglot/xml/TestReaderComparedToDefault.java
%pom_remove_dep com.cedarsoftware:java-util polyglot-xml

# ComparisonFailure
rm polyglot-yaml/src/test/java/org/sonatype/maven/polyglot/yaml/SnakeYamlModelReaderTest.java

%{mvn_alias} ':polyglot-{*}' io.tesla.polyglot:tesla-polyglot-@1
%{mvn_alias} ':polyglot-{*}' org.sonatype.pmaven:pmaven-@1

%{mvn_file} :{*} %{base_name}/@1

%if %{with bootstrap}
%{mvn_package} :polyglot __noinstall
%endif

%build
%{mvn_build} \
%if %{without bootstrap}
	-s \
%endif
	-f -- \
	-Dproject.build.sourceEncoding=UTF-8 \
	-Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%if %{with bootstrap}
%files -f .mfiles
%license LICENSE.txt license-header.txt

%else

%files -f .mfiles-polyglot
%doc poms README.md
%license LICENSE.txt license-header.txt

%files atom -f .mfiles-polyglot-atom

%files groovy -f .mfiles-polyglot-groovy

%files java -f .mfiles-polyglot-java

%files yaml -f .mfiles-polyglot-yaml

%files maven-plugin -f .mfiles-polyglot-maven-plugin

%files translate-plugin -f .mfiles-polyglot-translate-plugin

%files xml -f .mfiles-polyglot-xml
%doc polyglot-xml/README.md

%endif

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt license-header.txt

%changelog
* Fri Dec 17 2021 fstrba@suse.com
- Do not generate test stubs by gmavenplus-plugin, since we are not
  building or running tests during build
* Mon Jan 18 2021 fstrba@suse.com
- Require jdk >= 1.8 for building
- Build always with source/target level 8, since the code contains
  constructs that are 8+ only
* Thu Dec 10 2020 fstrba@suse.com
- Upgrade to upstream version 0.4.5
  * Version 0.4.5 - 2020-03-03
    + Remove upper bound for JDK version to allow Java 11 and newer
    + polyglot-kotlin - revert automatic source folder setting to
    koltin
    + Update xstream version in test resources to avoid security
    alerts
    + Avoid assumption about replacement pom file being readable
    + Fix sorting in model manager
    + Upgrade scala-maven-plugin, clojure-maven-plugin and Clojure
  * Version 0.4.4 - 2019-11-24
    + polyglot-kotlin: Set source folders to kotlin
    + Upgrade to kotlin 1.3.60
    + Provide a mechanism to override properties of a polyglot build
    + TeslaModelProcessor.locatePom(File) ignores files ending
    in.xml
    + Use platform encoding in ModelReaderSupport
    + Invoker plugin update
    + takari parent update
    + plexus-component-metadata update to 2.1.0
    + maven-enforcer-plugin update to 3.0.0-M3
  * Version 0.4.3 - 2019-08-14
    + polyglot-kotlin: Avoid IllegalStateException
  * Version 0.4.2 - 2019-08-01
    + polyglot-kotlin: improved support for IntelliJ Idea usage
  * Version 0.4.1 - 2019-06-04
    + polyglot-kotlin: kotlin update and numerous improvements to
    more idiomatic kotlin
  * Version 0.4.0 - 2019-03-09
    + polyglot-common:
    Execute tasks are now installed with inheritable set to
    false
    The ExecuteContext interface now has default
    implementations
    The ExecuteContext now includes getMavenSession()
    the ExecuteContext now includes getLog() to comport with
    Java bean conventions. The log() operation has been
    deprecated.
    the ExecuteContext now includes getBasedir() to comport with
    Java bean conventions. The basedir() operation has been
    deprecated.
    + polyglot-kotlin:
    Updates Kotlin to 1.3.21
    Includes support for Maven's ClassRealm
    Includes full support for the entire Maven model
    Includes support for execute tasks via as inline lambdas or
    as external scripts.
    Adds integration tests
    Provides 100%% test coverage for the entire Maven model
    Resolves ClassLoader issues that affected integration with
    IntelliJ IDEA
  * Version 0.3.2 - 2018-10-19
    + polyglot-java: fixed depMgt conversion
    + polyglot-ruby: java9+ support improvement
    + added polyglot-kotlin
  * Version 0.3.1 - 2018-06-27
    + polyglot-scala:
    Convenience methods for
    Dependency (classifier, intransitive, %% (scope))
    Support reporting-section in pom
    Added default value for pom property modelversion (4.0.0)
    Updated used Scala Version (2.11.12)
    refined Dependency.copy method
    Made output dir to pom.scala files compilation configurable
    via system property polyglot.scala.outputdir
    Improved support and docs for configuration elements of
    plugins
    + Upgrade to latest takari-pom parent
    + polyglot-yaml: Support for xml attributes
    + polyglot-yaml: exclude pomFile property from serialization
    + polyglot-java: Linux support and test fixes
    + polyglot-java: Moved examples into polyglot-maven-examples
  * Version 0.3.0 - 2018-03-07
    + Updated Scala version
    + Scala warning fixes
    + polyglot-scala: Scala syntax friendly include preprocessor
    + Added link to user of yml version
    + License and Central Repository badges
    + polyglot-scala: Use Zinc server for Scala module
    + polyglot-scala: Support more valid XML element name chars in
    dynamic Config
    + Experimental addition of Java as polyglot language:
- Added patch:
  * pomless-tycho.patch
    + allow building eclipse with our pomless tycho
* Sun Nov 24 2019 fstrba@suse.com
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Mon Nov 18 2019 fstrba@suse.com
- Enable the tesla-polyglot main flavour, since the dependencies
  are now present
* Sun Nov 10 2019 fstrba@suse.com
- Added patch:
  * polyglot-snakeyaml-1.25.patch
    + Fix build against snakeyaml-1.25
* Thu Nov  7 2019 fstrba@suse.com
- Initial packaging of tesla-polyglot 0.2.1
- Build as _multibuild
  * tesla-polyglot:bootstrap -> tesla-polyglot-common
  * tesla-polyglot
  - Disable this flavour, since we still lack dependencies for it
